// *** The user may change these wildcard strings to default MIDI ports
// Note that a "comment" line begins with a '//', meaning it's not real code!


var defaultMidiInPort = "";
var defaultMidiMergePort = "";
var defaultMidiOutPort = "";

// Example port assigments, with * being a "wildcard" (anything can match)
//defaultMidiInPort = "*PCR MIDI*";
//defaultMidiOutPort = "*NT:*8*";
//defaultMidiMergePort = "";

var baseOctave = -2;


function defaultVelocity()
{
	// "row" is the string number

	// String velocity: low threshold
	// Set this to the lowest average velocity each string produces
	patch.row[0].velLowIn = 30;
	patch.row[1].velLowIn = 30;
	patch.row[2].velLowIn = 30;
	patch.row[3].velLowIn = 30;
	patch.row[4].velLowIn = 30;
	patch.row[5].velLowIn = 30;

	// String velocity: high threshold
	// Set this to the highest average velocity each string produces
	patch.row[0].velHighIn = 100;
	patch.row[1].velHighIn = 100;
	patch.row[2].velHighIn = 100;
	patch.row[3].velHighIn = 100;
	patch.row[4].velHighIn = 100;
	patch.row[5].velHighIn = 100;

	// High and low values above with be scaled to these values below
	patch.velStringLow = 8;
	patch.velStringHigh = 127;
}


// *** The user may change values in the initMode() function to design own presets

function initMode(newMode)
{

	defaultVelocity();

	switch(newMode) {

	default: // MATCH THIS WITH YOUR DEFAULT MODE!
	case 1:  // YOUR EZ WILL INITIALIZE TO MODE #1!
		patch.name = "Fretboard";
		patch.description = "Mixes guitar and keyboard: tap-style, but with high-note priority.";
		patch.playStyle = PLAY_FRETBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 78;
		patch.row[1].baseNote = 73;
		patch.row[2].baseNote = 68;
		patch.row[3].baseNote = 63;
		patch.row[4].baseNote = 58;
		patch.row[5].baseNote = 53;
		break;

	case 2: // Fretboard 8vb
		patch.name = "Fretboard 8vb";
		patch.description = "Fretboard down an octave.";
		patch.playStyle = PLAY_FRETBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 66;
		patch.row[1].baseNote = 61;
		patch.row[2].baseNote = 56;
		patch.row[3].baseNote = 51;
		patch.row[4].baseNote = 46;
		patch.row[5].baseNote = 41;
		break;

	case 3: // Fretboard 8va
		patch.name = "Fretboard 8va";
		patch.description = "Fretboard up an octave.";
		patch.playStyle = PLAY_FRETBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 90;
		patch.row[1].baseNote = 85;
		patch.row[2].baseNote = 80;
		patch.row[3].baseNote = 75;
		patch.row[4].baseNote = 70;
		patch.row[5].baseNote = 65;
		break;

	case 4:
		patch.name = "Keyboard Grid";
		patch.description = "Polyphonic, tuned in perfect fourths across the board.";
		patch.playStyle = PLAY_KEYBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 78;
		patch.row[1].baseNote = 73;
		patch.row[2].baseNote = 68;
		patch.row[3].baseNote = 63;
		patch.row[4].baseNote = 58;
		patch.row[5].baseNote = 53;
		break;

	case 5:
		patch.name = "Keyboard, Octave Down";
		patch.description = "Keyboard grid, octave DOWN, tuned in perfect fourths across the board.";
		patch.playStyle = PLAY_KEYBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 66;
		patch.row[1].baseNote = 61;
		patch.row[2].baseNote = 56;
		patch.row[3].baseNote = 51;
		patch.row[4].baseNote = 46;
		patch.row[5].baseNote = 41;
		break;

	case 6:
		patch.name = "Keyboard, Octave Up";
		patch.description = "Keyboard grid, octave UP, tuned in perfect fourths across the board.";
		patch.playStyle = PLAY_KEYBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 90;
		patch.row[1].baseNote = 85;
		patch.row[2].baseNote = 80;
		patch.row[3].baseNote = 75;
		patch.row[4].baseNote = 70;
		patch.row[5].baseNote = 65;
		break;

	case 7:
		patch.name = "Guitar";
		patch.description = "Standard guitar tuning: EADGBE";
		patch.playStyle = PLAY_GUITAR;
		patch.velOrig = 16;
		patch.velHammer = 64;
		patch.velPull = 48;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 2;
		patch.row[2].channel = 3;
		patch.row[3].channel = 4;
		patch.row[4].channel = 5;
		patch.row[5].channel = 6;
		// Base note for the first fret per row
		patch.row[0].baseNote = 65;
		patch.row[1].baseNote = 60;
		patch.row[2].baseNote = 56;
		patch.row[3].baseNote = 51;
		patch.row[4].baseNote = 46;
		patch.row[5].baseNote = 41;
		break;

	case 8:
		patch.name = "Guitar, Octave Down";
		patch.description = "Octave down guitar tuning, for bass-style playing";
		patch.playStyle = PLAY_GUITAR;
		patch.velOrig = 16;
		patch.velHammer = 64;
		patch.velPull = 48;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 2;
		patch.row[2].channel = 3;
		patch.row[3].channel = 4;
		patch.row[4].channel = 5;
		patch.row[5].channel = 6;
		// Base note for the first fret per row
		patch.row[0].baseNote = 53;
		patch.row[1].baseNote = 48;
		patch.row[2].baseNote = 44;
		patch.row[3].baseNote = 39;
		patch.row[4].baseNote = 34;
		patch.row[5].baseNote = 29;
		break;

	case 9:
		patch.name = "Guitar, Octave Up";
		patch.description = "Octave up guitar tuning, for high-strung playing";
		patch.playStyle = PLAY_GUITAR;
		patch.velOrig = 16;
		patch.velHammer = 64;
		patch.velPull = 48;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 2;
		patch.row[2].channel = 3;
		patch.row[3].channel = 4;
		patch.row[4].channel = 5;
		patch.row[5].channel = 6;
		// Base note for the first fret per row
		patch.row[0].baseNote = 77;
		patch.row[1].baseNote = 72;
		patch.row[2].baseNote = 68;
		patch.row[3].baseNote = 63;
		patch.row[4].baseNote = 58;
		patch.row[5].baseNote = 53;
		break;

	case 10:
		patch.name = "Tidy Guitar";
		patch.description = "Guitar mode, but with open strings disabled.";
		patch.playStyle = PLAY_GUITAR;
		patch.velOrig = 16;
		patch.velHammer = 64;
		patch.velPull = 48;
		patch.openStr = false;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 65;
		patch.row[1].baseNote = 60;
		patch.row[2].baseNote = 56;
		patch.row[3].baseNote = 51;
		patch.row[4].baseNote = 46;
		patch.row[5].baseNote = 41;
		break;

	case 11:
		patch.name = "Squeaky Clean Guitar";
		patch.description = "Guitar mode, open strings disabled, only plucked notes sound!";
		patch.playStyle = PLAY_GUITAR;
		patch.velOrig = 0;
		patch.velHammer = 0;
		patch.velPull = 0;
		patch.openStr = false;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 65;
		patch.row[1].baseNote = 60;
		patch.row[2].baseNote = 56;
		patch.row[3].baseNote = 51;
		patch.row[4].baseNote = 46;
		patch.row[5].baseNote = 41;
		break;

	case 12:
		patch.name = "Continuous Chord Guitar";
		patch.description = "Guitar mode, only plucked notes sound, notes sustain until next note (or muted)";
		patch.playStyle = PLAY_CONTINUOUS;
		patch.velOrig = 0;
		patch.velHammer = 0;
		patch.velPull = 0;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 65;
		patch.row[1].baseNote = 60;
		patch.row[2].baseNote = 56;
		patch.row[3].baseNote = 51;
		patch.row[4].baseNote = 46;
		patch.row[5].baseNote = 41;
		break;

	case 13:
		patch.name = "Continuous Chord Guitar (Clean)";
		patch.description = "Guitar mode, only plucked notes sound, notes sustain until next note (or muted), no open strings!";
		patch.playStyle = PLAY_CONTINUOUS;
		patch.velOrig = 0;
		patch.velHammer = 0;
		patch.velPull = 0;
		patch.openStr = false;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 1;
		patch.row[2].channel = 1;
		patch.row[3].channel = 1;
		patch.row[4].channel = 1;
		patch.row[5].channel = 1;
		// Base note for the first fret per row
		patch.row[0].baseNote = 65;
		patch.row[1].baseNote = 60;
		patch.row[2].baseNote = 56;
		patch.row[3].baseNote = 51;
		patch.row[4].baseNote = 46;
		patch.row[5].baseNote = 41;
		break;
/*
	case 17: // Solo Double Bass
		patch.name = "GPO Double Bass";
		patch.description = "Solo double bass mode for Garritan Personal Orchestra.";
		patch.playStyle = PLAY_FRETBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 2;
		patch.row[2].channel = 3;
		patch.row[3].channel = 4;
		patch.row[4].channel = 0;
		patch.row[5].channel = 6;
		// Base note for the first fret per row
		patch.row[0].baseNote = 45;
		patch.row[1].baseNote = 38;
		patch.row[2].baseNote = 31;
		patch.row[3].baseNote = 24;
		patch.row[4].baseNote = 0;
		patch.row[5].baseNote = 57;
		break;

	case 18: // Solo Cello
		patch.name = "GPO Cello";
		patch.description = "Solo cello mode for Garritan Personal Orchestra.";
		patch.playStyle = PLAY_FRETBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 2;
		patch.row[2].channel = 3;
		patch.row[3].channel = 4;
		patch.row[4].channel = 0;
		patch.row[5].channel = 6;
		// Base note for the first fret per row
		patch.row[0].baseNote = 57;
		patch.row[1].baseNote = 50;
		patch.row[2].baseNote = 43;
		patch.row[3].baseNote = 36;
		patch.row[4].baseNote = 0;
		patch.row[5].baseNote = 69;
		break;

	case 19: // Solo Viola
		patch.name = "GPO Viola";
		patch.description = "Solo viola mode for Garritan Personal Orchestra.";
		patch.playStyle = PLAY_FRETBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 2;
		patch.row[2].channel = 3;
		patch.row[3].channel = 4;
		patch.row[4].channel = 0;
		patch.row[5].channel = 6;
		// Base note for the first fret per row
		patch.row[0].baseNote = 69;
		patch.row[1].baseNote = 62;
		patch.row[2].baseNote = 55;
		patch.row[3].baseNote = 48;
		patch.row[4].baseNote = 0;
		patch.row[5].baseNote = 81;
		break;

	case 20: // Solo Violin
		patch.name = "GPO Violin";
		patch.description = "Solo violin mode for Garritan Personal Orchestra.";
		patch.playStyle = PLAY_FRETBOARD;
		patch.velOrig = 100;
		patch.velHammer = 100;
		patch.velPull = 100;
		// Channel 1-16
		patch.row[0].channel = 1;
		patch.row[1].channel = 2;
		patch.row[2].channel = 3;
		patch.row[3].channel = 4;
		patch.row[4].channel = 0;
		patch.row[5].channel = 6;
		// Base note for the first fret per row
		patch.row[0].baseNote = 76;
		patch.row[1].baseNote = 69;
		patch.row[2].baseNote = 62;
		patch.row[3].baseNote = 55;
		patch.row[4].baseNote = 0;
		patch.row[5].baseNote = 88;
		break;
*/
	}

}

