var patch = new ezPatch();

var keyTest = 0;
var configMode = 1;
var nextCcScan = false;
var changeWindow = 0;

function changeMode(newMode)
{
	// Makes sure all previous notes are killed
	if(midiOut) {
		patch.panic();
		allNotesOff();
	}

	// Default all patch properties
	patch.reset();

	// Record the new mode (corresponds to Sound Number on the guitar's display)
	configMode = newMode;

	initMode(newMode);

	guiUpdate();

}

function modeIncr()
{
	configMode += 1;
	if(configMode > 20) configMode = 1;
	changeMode(configMode);
}

function modeDecr()
{
	configMode -= 1;
	if(configMode < 1) configMode = 20;
	changeMode(configMode);
}




function modeByProgram(dat1)
{
	switch(dat1) {
	case 0x19: // Sound 1 & 3
		// Get next event: should be Volume (CC#7)
		nextCcScan = true;
		break;
	case 0x18: // Sound 2
		changeMode(2);
		break;
	case 0x1A: // Sound 4 & 5
		if(configMode == 3 || configMode == 5) {
			changeMode(4);
		} else if(configMode == 4 || configMode == 6) {
			changeMode(5);
		}
		break;
	case 0x1B: // Sound 6
		changeMode(6);
		break;
	case 0x1C: // Sound 7
		changeMode(7);
		break;
	case 0x1D: // Sound 8
		changeMode(8);
		break;
	case 0x1E: // Sound 9
		changeMode(9);
		break;
	case 0x20: // Sound 10
		changeMode(10);
		break;
	case 0x21: // Sound 11
		changeMode(11);
		break;
	case 0x22: // Sound 12
		changeMode(12);
		break;
	case 0x23: // Sound 13
		changeMode(13);
		break;
	case 0x24: // Sound 14
		changeMode(14);
		break;
	case 0x26: // Sound 15 & 16
		if(configMode == 14 || configMode == 16) {
			changeMode(15);
		} else if(configMode == 15 || configMode == 17) {
			changeMode(16);
		}
		break;
	case 0x27: // Sound 17
		changeMode(17);
		break;
	case 0x69: // Sound 18
		changeMode(18);
		break;
	case 0x6A: // Sound 19
		changeMode(19);
		break;
	case 0x00: // Sound 20
		changeMode(20);
		break;
	}


}

function allNotesOff()
{
	var arCh = new Array(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);

	for(var ri = 0; ri < 6; ri++) {
		if(! arCh[patch.row[ri].channel-1]++) {
			if(patch.row[ri].channel > 0)
			OutputMidiMsg( -1, 0xB0, patch.row[ri].channel, 123, 0);
		}
	}
	//PrintLn("All Notes Off");
}

function allSoundOff()
{
	var arCh = new Array(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);

	for(var ri = 0; ri < 6; ri++) {
		if(! arCh[patch.row[ri].channel-1]++) {
			if(patch.row[ri].channel > 0)
			OutputMidiMsg( -1, 0xB0, patch.row[ri].channel, 120, 0);
		}
	}
	//PrintLn("All Sound Off");
}



function OutputMidiMsg( port, status, ch, dt1, dt2, tm)
{
	if(port == -1) port = midiOut;

	if(port == 0) {
		// No output selected!
		return;
	}

	if((status >> 4) < 0x8 || (status >> 4) > 0xE) {
		alert("Bad status nibble: " + status);
		return;
	}

	if(ch > 16 || ch < 1) {
		alert("Bad channel nibble: " + ch);
		return;
	}
	ch--;

	if(dt1 > 127 || dt1 < 0 || dt2 > 127 || dt2 < 0) {
		alert("Bad data byte nibble: " + dt1 + " " + dt2);
		return;
	}

	if(tm == null) {
		tm = -1;
	}

	SendMidi(port, tm, status | ch, dt1, dt2);
	//SendMidi(port, Midi.GetMasterClockTime()+10000, status, dt1, dt2);
}



function processMessage(fnId, row, fret)
{
	//PrintLn(fnId+" : "+row+" : "+fret);

	if(!midiOut) {
		return;
	}

	switch(fnId) {
	case 0x01: // Note On
		row--;
		fret = fret - fretBase[row];
		PrintLn("Fret On: row " + (row+1) + " fret " + (fret+1));
		patch.fretOn(row, fret);
		break;
	case 0x02: // Note Off
		row--;
		fret = fret - fretBase[row];
		PrintLn("Fret Off: row " + (row+1) + " fret " + (fret+1));
		patch.fretOff(row, fret);
		break;
	case 0x03: // Fret light on
		break;
	case 0x04: // Fret light off
		break;
	case 0x05: // String velocity
		// OutputMidiMsg( -1, 0x90 | (10-1), (6-row)+48, fret );
		// TODO: Must also send Note Off (0x80) a few ticks later
		PrintLn("Pluck: row " + (row) + " vel " + fret);
		row--;
		if(patch.stringPluck) patch.stringPluck(row, fret);
		break;
	case 0x06: // +/- Buttons
		if(row == 0x00 && fret == 0x7F) {
			// + button press
			if(patch.plusButtonPress) patch.plusButtonPress();
			break;
		} else if(row == 0x00 && fret == 0x00) {
			// + button release
			if(patch.plusButtonRelease) patch.plusButtonRelease();
			break;
		} else if(row == 0x01 && fret == 0x7F) {
			// - button press
			if(patch.minusButtonPress) patch.minusButtonPress();
			break;
		} else if(row == 0x01 && fret == 0x00) {
			// - button release
			if(patch.minusButtonRelease) patch.minusButtonRelease();
			break;
		}
		return 1;
		break;
	case 0x07: // mode Buttons
		if(row == 0x00 && fret == 0x7F) {
			// Sound Select button down
			if(patch.soundButtonPress) patch.soundButtonPress();
			break;
		} else if(row == 0x00 && fret == 0x00) {
			// Sound Select button up
			if(patch.soundButtonRelease) patch.soundButtonRelease();
			break;
		} else if(row == 0x01 && fret == 0x7F) {
			// Song Select button down
			if(patch.songButtonPress) patch.songButtonPress();
			break;
		} else if(row == 0x01 && fret == 0x00) {
			// Song Select button up
			if(patch.songButtonRelease) patch.songButtonRelease();
			break;
		}
		return 1;
		break;
	default:
		return 1;
		break;
	}
	return 0;
}


function hexValue( hstr )
{
	var hexdigits = "0123456789ABCDEF";

	return (hexdigits.indexOf(hstr.charAt(0))*16) + hexdigits.indexOf(hstr.charAt(1))
}


function SendSysExString( sysStr )
{
	var port = midiOut;

	if(port == 0) {
		// No output specified
		return;
	}

	var tm = -1;

	SendSysEx(port, tm, sysStr)
}

// [0] 0xF0 == Sysex start
// [1] 0x43 == Yamaha
// [2] 0x7F == RealTime message ID
// [3] 0x00
// [4] 0x00
// [5] 0x0n == Message type...
			// 01 Note On
			// 02 Note Off
			// 03 Fret LED On
			// 04 Fret LED Off
			// 05 String Data
			// 06 Switch Data (Control)
			// 07 Switch Data (Mode)
// [6] 0x0n == String 1-6 (high-low)
// [7] 0xnn == Note Number (or Velocity)
// [8] 0xF7 == End Sysex

function On_SysExInput( port, sysStr )
{
	if(port != midiIn) {
		return;
	}

	//PrintLn("Sysex: "+sysStr);
	//return;

	var sysArr = sysStr.split(" ");

// 240 67 127 0 0 4 3 76 247

	if(sysArr[1] != "67" || sysArr[2] != "127") {
		// Not Yamaha sysex, or not realtime message
		//mox.SendSysExString(sysStr);
		PrintLn("Not proper sysex");
		return;
	}

	//if(processMessage(hexValue(sysArr[5]), hexValue(sysArr[6]), hexValue(sysArr[7]))) {
	if(processMessage(parseInt(sysArr[5]), parseInt(sysArr[6]), parseInt(sysArr[7]))) {
		PrintLn("Sysex parse failure");
		//mox.SendSysExString(sysStr);
	}
}


function On_MidiMerge( port, stat, dat1, dat2, ts )
{
	var msgtype = stat & 0xF0;   // Message type
	var msgchan = stat & 0x0F;   // Message channel

//alert("merge: " + msgtype + ":" + msgchan);
//return;

	switch(msgtype) {
	case 0x90: // Note On
	case 0x80: // Note Off
				OutputMidiMsg( -1, msgtype, msgchan+1, dat1, dat2);
				break;
	default:
//case 0xB0: // CC
		// Echo CC message once for each used port

		var arCh = new Array(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);

		for(var ri = 0; ri < 6; ri++) {
			if(! arCh[patch.row[ri].channel-1]++) {
				if(patch.row[ri].channel > 0)
//				OutputMidiMsg( -1, 0xB0, patch.row[ri].channel, dat1, dat2);
				OutputMidiMsg( -1, msgtype, patch.row[ri].channel, dat1, dat2);
			}
		}

		break;
   }
}


function On_MidiInput( port, stat, dat1, dat2, ts )
{
	if(port == midiMerge) {
		On_MidiMerge( port, stat, dat1, dat2, ts );
		return;
	}

	if(port != midiIn) {
		return;
	}

	var msgtype = stat & 0xF0;   // Message type
	var msgchan = stat & 0x0F;   // Message channel

	switch(msgtype) {
	case 0x90: // Note On
	case 0x80: // Note Off
		if(keyTest) {
			//processMessage(fnId, row, fret)
			processMessage( msgtype == 0x90 ? (dat2 ? 1 : 2 ) : 2, 1, dat1 );
		}
		// Else omit these messages from stream
		break;
	case 0xB0: // CC
		if(changeWindow) {

			if(nextCcScan) {
				// Waiting for volume message to determine correct program change...
				if(msgchan == 0x00 && dat1 == 0x07 && dat2 == 0x69) {
					changeMode(1);
				} else {
					changeMode(3);
				}
				nextCcScan = false;
				break;
			}

			if(dat1 == 10 && msgchan == 5) {
				// Pan message on channel 6 means leaving change window
				changeWindow = 0;
				break;
			}

	  } else {

			if(dat1 == 0 && msgchan == 0) {
				// Bank message on channel 1 means entering change window
				changeWindow = 1;
				break;
			}

			// Otherwise, interpret literally
			//OutputMidiMsg( -1, 0xB0, 1, dat1, dat2);

			// Send out one message per string in use!
			var arCh = new Array(0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);

			for(var ri = 0; ri < 6; ri++) {
				if(! arCh[patch.row[ri].channel-1]++) {
					if(patch.row[ri].channel > 0)
	//				OutputMidiMsg( -1, 0xB0, patch.row[ri].channel, dat1, dat2);
					OutputMidiMsg( -1, msgtype, patch.row[ri].channel, dat1, dat2);
				}
			}

		}
		break;
	case 0xC0: // Program change
		if(msgchan == 0x00) {
			modeByProgram(dat1);
		}
		break;
	case 0xE0: // Pitch wheel
		if(msgchan == 0x01) {
			if(patch.pitchWheel) patch.pitchWheel( parseInt(dat1), parseInt(dat2) );
		}
		break;
	default: // All others
		//OutputMidiMsg( -1, stat, dat1, dat2 );
		break;
   }
}

